Method: Redisk::IO#sync
- Defined in:
- lib/redisk/io.rb
#sync ⇒ Object
ios.sync => true or false Returns the current “sync mode’’ of ios. When sync mode is true, all output is immediately flushed to the underlying operating system and is not buffered by Ruby internally. See also IO#fsync.
f = File.new("testfile")
f.sync #=> false
919 920 921 |
# File 'lib/redisk/io.rb', line 919 def sync @sync end |